/*
 * Copyright 2002-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.beans;

import org.junit.Test;

import org.springframework.tests.sample.beans.TestBean;

import static org.junit.Assert.*;

/**
 * Unit tests for {@link DirectFieldAccessor}
 *
 * @author Jose Luis Martin
 * @author Chris Beams
 */
public class DirectFieldAccessorTests extends AbstractConfigurablePropertyAccessorTests {

	@Override
	protected ConfigurablePropertyAccessor createAccessor(Object target) {
		return new DirectFieldAccessor(target);
	}

	@Test
	public void withShadowedField() throws Exception {
		@SuppressWarnings("serial")
		TestBean tb = new TestBean() {
			@SuppressWarnings("unused")
			StringBuilder name = new StringBuilder();
		};

		DirectFieldAccessor dfa = new DirectFieldAccessor(tb);
		assertEquals(StringBuilder.class, dfa.getPropertyType("name"));
	}

}
